@@ -93,16 +93,15 @@ class Task(EventMixin):
             queue = self.queue
             local = self.local
 
-        desc = self.get_task_description(args, kwargs)
-        desc['id'] = uuid1().hex
         channel = LazyChannel.from_config(self.kuyruk.config)
+        queue = Queue(queue, channel, local)
+        desc = self.get_task_description(args, kwargs, queue.name)
         with channel:
-            queue = Queue(queue, channel, local)
             queue.send(desc)
 
         return desc['id']
 
-    def get_task_description(self, args, kwargs):
+    def get_task_description(self, args, kwargs, queue):
         """Return the dictionary to be sent to the queue."""
 
         # For class tasks; replace the first argument with the id of the object
@@ -111,13 +110,15 @@ class Task(EventMixin):
             args[0] = args[0].id
 
         return {
+            'queue': queue,
+            'args': args,
+            'kwargs': kwargs,
             'module': self.module_name,
             'function': self.f.__name__,
             'class': self.class_name,
-            'args': args,
-            'kwargs': kwargs,
-            'timestamp': datetime.utcnow(),
             'retry': self.retry,
+            'id': uuid1().hex,
+            'timestamp': datetime.utcnow(),
         }
 
     @profile
